# PersonV30Rc2

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDateV30Rc2**](LastModifiedDateV30Rc2.md) |  | [optional] 
**name** | [**NameV30Rc2**](NameV30Rc2.md) |  | [optional] 
**other_names** | [**OtherNamesV30Rc2**](OtherNamesV30Rc2.md) |  | [optional] 
**biography** | [**BiographyV30Rc2**](BiographyV30Rc2.md) |  | [optional] 
**researcher_urls** | [**ResearcherUrlsV30Rc2**](ResearcherUrlsV30Rc2.md) |  | [optional] 
**emails** | [**EmailsV30Rc2**](EmailsV30Rc2.md) |  | [optional] 
**addresses** | [**AddressesV30Rc2**](AddressesV30Rc2.md) |  | [optional] 
**keywords** | [**KeywordsV30Rc2**](KeywordsV30Rc2.md) |  | [optional] 
**external_identifiers** | [**PersonExternalIdentifiersV30Rc2**](PersonExternalIdentifiersV30Rc2.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

